@@ -579,7 +579,7 @@ def nlpclassify(maadstoken,iscategory,maads_rest_url,thefile='',theserverlocalna
     r = requests.post(maads_rest_url, files)
     msg = r.text
 
-    if csvonly:
+    if csvonly==1:
       localname=username + '_' + filename + '_nlpclassify_' + str(iscategory) + '_.csv'
       baseurl=urljoin(maads_rest_url,'/')
       url = "%smaadsweb/csvtemps/%s" % (baseurl,localname)
